import setuptools

setuptools.setup(
    name="simplecalculator24",
    version="0.0.1",
    author="Shravani Mpore",
    author_email="shramore58@gmail.com",
    description="Package to get calculator",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires= '>=3.7',
)
